@@ -20,9 +20,13 @@ CREATE TABLE Sales
   PostalCode VARCHAR(10) NOT NULL,
   Country VARCHAR(50) NOT NULL,
   BookId INTEGER,
+  Coupon_Id INTEGER,
   PeriodEndDate DATE,
   TotalAmount FLOAT,  
   SalesDataId INTEGER,
   CONSTRAINT FK_Sales_Regions FOREIGN KEY (PostalCode, Country) REFERENCES Regions (PostalCode, Country),
   CONSTRAINT FK_Sales_SalesData FOREIGN KEY (SalesDataId) REFERENCES SalesData (SalesDataId)
 );
+
+-- AcrossDatabase test for foreign keys
+ALTER TABLE Sales ADD CONSTRAINT FK_Sales_Book FOREIGN KEY (BookId) REFERENCES BOOKS.Books (Id);
